@@ -18,8 +18,6 @@
 #define CONFFILENAME  "/.wmcalc"
 #define CONFTEMPFILE  "/tmp/wmcalc.tmp"
 #define CONFIGGLOBAL  CONF"/wmcalc.conf"
-#define VER           0
-#define REL           5
 
 #define LMASK         100
 #define MMASK         200
