@@ -4,16 +4,16 @@
  *  Date:     November 1, 2000
  *  Author:   Edward H. Flora <ehflora@access1.net>
  *
- *  This file is a part of the wmcalc application.  As such, this 
- *  file is licensed under the GNU General Public License, version 2.  
- *  A copy of this license may be found in the file COPYING that should 
- *  have been distributed with this file.  If not, please refer to 
+ *  This file is a part of the wmcalc application.  As such, this
+ *  file is licensed under the GNU General Public License, version 2.
+ *  A copy of this license may be found in the file COPYING that should
+ *  have been distributed with this file.  If not, please refer to
  *  http://www.gnu.org/copyleft/gpl.html for details.
  *
  ****************************************************************
     Description:
-      This file contains system level functions, such as read/write of 
-      the config file, character map boundaries, etc. 
+      This file contains system level functions, such as read/write of
+      the config file, character map boundaries, etc.
 
     Change History:
     Date       Modification
@@ -80,7 +80,7 @@ void ExecFunc( int val ) {
     multnums();
     break;
   case 111:
-    // scinotation();
+    /* scinotation(); */
     startcalc();
     break;
   case 112:
@@ -115,7 +115,7 @@ void ExecFunc( int val ) {
     break;
   case 201:
     sqrtnum();
-    //    userdef201();
+    /*    userdef201(); */
     break;
   case 202:
     recallmem(7);
@@ -128,11 +128,11 @@ void ExecFunc( int val ) {
     break;
   case 205:
     divnums();
-    //    userdef205();
+    /*    userdef205(); */
     break;
   case 206:
     sqrnum();
-    //    userdef206();
+    /*    userdef206(); */
     break;
   case 207:
     recallmem(4);
@@ -145,7 +145,7 @@ void ExecFunc( int val ) {
     break;
   case 210:
     multnums();
-    //    userdef210();
+    /*    userdef210(); */
     break;
   case 211:
     startcalc();
@@ -161,7 +161,7 @@ void ExecFunc( int val ) {
     break;
   case 215:
     subtnums();
-    //    userdef215();
+    /*    userdef215(); */
     break;
   case 216:
     chgsignnum();
@@ -170,21 +170,21 @@ void ExecFunc( int val ) {
     recallmem(0);
     break;
   case 218:
-    //    userdef218();
+    /*    userdef218(); */
     break;
   case 219:
     equalfunc();
     break;
   case 220:
     addnums();
-    //    userdef220();
+    /*    userdef220(); */
     break;
   case 300:
     clearnum();
     break;
   case 301:
     sqrtnum();
-    //    userdef301();
+    /*    userdef301(); */
     break;
   case 302:
     stormem(7);
@@ -197,11 +197,11 @@ void ExecFunc( int val ) {
     break;
   case 305:
     divnums();
-    //    userdef305();
+    /*    userdef305(); */
     break;
   case 306:
     sqrnum();
-    //    userdef306();
+    /*    userdef306(); */
     break;
   case 307:
     stormem(4);
@@ -214,7 +214,7 @@ void ExecFunc( int val ) {
     break;
   case 310:
     multnums();
-    //    userdef310();
+    /*    userdef310(); */
     break;
   case 311:
     startcalc();
@@ -230,7 +230,7 @@ void ExecFunc( int val ) {
     break;
   case 315:
     subtnums();
-    //    userdef315();
+    /*    userdef315(); */
     break;
   case 316:
     chgsignnum();
@@ -239,14 +239,14 @@ void ExecFunc( int val ) {
     stormem(0);
     break;
   case 318:
-    //    userdef318();
+    /*    userdef318(); */
     break;
   case 319:
     equalfunc();
     break;
   case 320:
     addnums();
-    //    userdef320();
+    /*    userdef320(); */
     break;
   } /* End of switch statement */
 
@@ -256,8 +256,8 @@ void ExecFunc( int val ) {
  *  Function:     getboundaries
  ****************************************************************
     Description:
-      This function returns the x,y boundaries for each character 
-      that is to be displayed on the display.  
+      This function returns the x,y boundaries for each character
+      that is to be displayed on the display.
 
       There must be a better way to do this, as by changing the file
       charmap.xpm, one may have to adjust these constants.
@@ -379,7 +379,7 @@ ButtonArea getboundaries(char ch) {
       This function updates the configuration file as memory locations
       are updated in the program.  It re-writes the entire file, but
       should ignore all lines that do not start with "Mem".
-      
+
     Change History:
     Date       Modification
     11/01/00   Function Header updated
@@ -398,35 +398,35 @@ int write_config(void) {
   char movefilecmd[2 * CONFIGFILEMAX + 10];  /* make sure enough room in string */
 
   /* Open current Config file */
-  if ((fp = fopen(configfile, "r")) == NULL) {  // Can't find config file
+  if ((fp = fopen(configfile, "r")) == NULL) {  /* Can't find config file */
     printf("%s: Cannot create configuration file\n", configfile);
     return(ERR_FILE_NOT_FOUND);
   }
 
   /* We cannot write to the global config-file... */
   if(!strcmp(configfile, CONFIGGLOBAL)) {
-    strcpy(configfile, getenv("HOME"));  // Added to wmbutton by Gordon Fraser, 9/21/01
-    strcat(configfile, CONFFILENAME);    
+    strcpy(configfile, getenv("HOME"));  /* Added to wmbutton by Gordon Fraser, 9/21/01 */
+    strcat(configfile, CONFFILENAME);
   }
 
   /* Open Temporary File */
-  if ((fptmp = fopen(tempfile, "w")) == NULL) {  // Can't open file in /tmp
+  if ((fptmp = fopen(tempfile, "w")) == NULL) {  /* Can't open file in /tmp */
     fprintf(stderr, "%s: Temporary File Open Failed\n", tempfile);
     strcpy(tempfile, getenv("HOME"));
     strcat(tempfile, "wmcalc.tmp");
-    if ((fptmp = fopen(tempfile, "w")) == NULL) {  // Can't open file in HOME
+    if ((fptmp = fopen(tempfile, "w")) == NULL) {  /* Can't open file in HOME */
       fprintf(stderr, "%s: Temporary File Open Failed\n", tempfile);
       return(ERR_TMP_FILE_FAILED);
     }
   }
 
-  while ((line = readln(fp)) != NULL) {    // Read Lines in config file
+  while ((line = readln(fp)) != NULL) {    /* Read Lines in config file */
     if (Verbose)  printf("line:%s", line);
 
-    if ((strncmp(line, CfgVarList[MEM_LABEL_0], 
+    if ((strncmp(line, CfgVarList[MEM_LABEL_0],
 		 strlen(CfgVarList[MEM_LABEL_0]) - 1) == 0)) {
-      // -1 to generalize to all Mem? strings
-      // If we've found a memory entry
+      /* -1 to generalize to all Mem? strings */
+      /* If we've found a memory entry */
       mem_ndx = atoi(line+strlen(CfgVarList[MEM_LABEL_0])-1);
       if ((mem_ndx >= 0) && (mem_ndx <= (NUM_MEM_CELLS - 1))) {
 	fprintf(fptmp,  "%s\t%f\n", CfgVarList[mem_ndx],
@@ -445,9 +445,9 @@ int write_config(void) {
 
   /* Copy temp file over original */
   /* Note:  If changing command, make sure to adjust size of string above!! */
-  sprintf(movefilecmd, "mv -f %s %s\n", tempfile, configfile); 
+  sprintf(movefilecmd, "mv -f %s %s\n", tempfile, configfile);
   err_code = system(movefilecmd);
-  
+
   if(Verbose) printf("New config file written.\n");
 
   return(err_code);
@@ -461,7 +461,7 @@ int write_config(void) {
      This function reads the configuration file on program startup,
      and sets the appropriate configuration options.
      (By default, this is ~/.wmcalc, or a user set value)
-    
+
     Change History:
     Date       Modification
     11/01/00   Function header updated.
@@ -479,34 +479,31 @@ int read_config(void) {
   int i = 0;
   int err_code = OKAY;
   char *line   = NULL;
-  char *sepstr = NULL;
   char  sep_ch = '\t';
   char *cfg_var_ptr = NULL;
 
 
-  sepstr = &sep_ch;
-
-  if ((fp = fopen(configfile, "r")) == NULL) {    // Can't find config file
-    strcpy(configfile, CONFIGGLOBAL);             // ...so try to open global config
-    if ((fp = fopen(configfile, "r")) == NULL) {  // Can't find global config file
+  if ((fp = fopen(configfile, "r")) == NULL) {    /* Can't find config file */
+    strcpy(configfile, CONFIGGLOBAL);             /* ...so try to open global config */
+    if ((fp = fopen(configfile, "r")) == NULL) {  /* Can't find global config file */
       fprintf(stderr, "%s: Configuration File not found\n", configfile);
       return(ERR_FILE_NOT_FOUND);
     } else {
-      write_config();                             // if global config opened, save in homedir
+      write_config();                             /* if global config opened, save in homedir */
     }
   }
   else {
     if (Verbose) printf("%s: Found Configuration File\n", configfile);
   }
 
-  do {                               // Read Lines in config file
+  do {                               /* Read Lines in config file */
     line = readln(fp);
     if (Verbose) printf("Line Read:%s\n", line);
-    if (line == NULL) break;         // if end of file, quit
-    if ( (line[0] != '#') && (line[0] != '\n')) { /* Ignore comments and 
+    if (line == NULL) break;         /* if end of file, quit */
+    if ( (line[0] != '#') && (line[0] != '\n')) { /* Ignore comments and
 						     blanks */
       if (strchr(line, sep_ch) != NULL) {  /* The line has a tab, so let's
-					      see if the variable is 
+					      see if the variable is
 					      understood */
 	i = 0;
 	/* Loop while we haven't found the variable */
@@ -517,10 +514,10 @@ int read_config(void) {
 	/* If we've found the variable, let's set the appropriate value */
 	if (i <= MAX_LABEL) {
 	  if (Verbose) printf("Variable %s found\n", CfgVarList[i]);
-	  
+
 	  /* Point to the 'tab' character, to read the value */
 	  cfg_var_ptr = strchr(line, sep_ch);
-	  cfg_var_ptr++;  // ++ to avoid tab character itself
+	  cfg_var_ptr++;  /* ++ to avoid tab character itself */
 
 	  /* Now set the appropriate variable */
 	  switch(i) {
@@ -538,7 +535,7 @@ int read_config(void) {
 	    MemLock[i] = 0;
 	    /* Set Memory Element */
 	    MemArray[i] = atof(cfg_var_ptr);
-	    if (Verbose) 
+	    if (Verbose)
 	      printf("Assign Memory Element %d to %f\n", i, MemArray[i]);
 	    break;
 
@@ -556,18 +553,18 @@ int read_config(void) {
 	    MemLock[i - MEM_LOCK_0] = 1;
 	    /* Set Memory Element */
 	    MemArray[i - MEM_LOCK_0] = atof(cfg_var_ptr);
-	    if (Verbose) 
+	    if (Verbose)
 	      printf("Assign Memory Element %d to %f\n", i -
 		     MEM_LOCK_0, MemArray[i - MEM_LOCK_0]);
 	    break;
 
 	  case IMAG_LABEL:
-	    /* Get the character that the user wishes to use to 
+	    /* Get the character that the user wishes to use to
 	       represent sqrt(-1) (i or j) */
 	    if ((cfg_var_ptr[0] == 'i') || cfg_var_ptr[0] == 'j') {
 	      ImagChar = cfg_var_ptr[0];
 	    }
-	    if (Verbose) 
+	    if (Verbose)
 	      printf("Use character '%c' to represent sqrt(-1)\n", ImagChar);
 	    break;
 
